@@ -1,24 +1,26 @@
 /*
-@licstart  The following is the entire license notice for the
-JavaScript code in this file.
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
 
-Copyright (C) 1997-2019 by Dimitri van Heesch
+ The MIT License (MIT)
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of version 2 of the GNU General Public License as published by
-the Free Software Foundation
+ Copyright (C) 1997-2020 by Dimitri van Heesch
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
 
-You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
 
-@licend  The above is the entire license notice
-for the JavaScript code in this file
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
 */
 var NAVTREE =
 [
@@ -51,8 +53,7 @@ var NAVTREE =
         ] ],
         [ "Comment blocks in Python", "docblocks.html#pythonblocks", null ],
         [ "Comment blocks in VHDL", "docblocks.html#vhdlblocks", null ],
-        [ "Comment blocks in Fortran", "docblocks.html#fortranblocks", null ],
-        [ "Comment blocks in Tcl", "docblocks.html#tclblocks", null ]
+        [ "Comment blocks in Fortran", "docblocks.html#fortranblocks", null ]
       ] ],
       [ "Anatomy of a comment block", "docblocks.html#docstructure", null ]
     ] ],
@@ -175,6 +176,7 @@ var NAVTREE =
       [ "Configuration options related to the XML output", "config.html#config_xml", null ],
       [ "Configuration options related to the DOCBOOK output", "config.html#config_docbook", null ],
       [ "Configuration options for the AutoGen Definitions output", "config.html#config_autogen", null ],
+      [ "Configuration options related to Sqlite3 output", "config.html#config_sqlite3", null ],
       [ "Configuration options related to the Perl module output", "config.html#config_perlmod", null ],
       [ "Configuration options related to the preprocessor", "config.html#config_preprocessor", null ],
       [ "Configuration options related to external references", "config.html#config_external", null ],
@@ -312,6 +314,10 @@ var NAVTREE =
       [ "\\verbinclude <file-name>", "commands.html#cmdverbinclude", null ],
       [ "\\htmlinclude [\"[block]\"] <file-name>", "commands.html#cmdhtmlinclude", null ],
       [ "\\latexinclude <file-name>", "commands.html#cmdlatexinclude", null ],
+      [ "\\rtfinclude <file-name>", "commands.html#cmdrtfinclude", null ],
+      [ "\\maninclude <file-name>", "commands.html#cmdmaninclude", null ],
+      [ "\\docbookinclude <file-name>", "commands.html#cmddocbookinclude", null ],
+      [ "\\xmlinclude <file-name>", "commands.html#cmdxmlinclude", null ],
       [ "\\a <word>", "commands.html#cmda", null ],
       [ "\\arg { item-description }", "commands.html#cmdarg", null ],
       [ "\\b <word>", "commands.html#cmdb", null ],
@@ -392,6 +398,9 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.8 Series", "changelog.html#log_1_8", [
+        [ "Release 1.8.20", "changelog.html#log_1_8_20", null ],
+        [ "Release 1.8.19", "changelog.html#log_1_8_19", null ],
+        [ "Release 1.8.18", "changelog.html#log_1_8_18", null ],
         [ "Release 1.8.17", "changelog.html#log_1_8_17", null ],
         [ "Release 1.8.16", "changelog.html#log_1_8_16", null ],
         [ "Release 1.8.15", "changelog.html#log_1_8_15", null ],
@@ -429,7 +438,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"custcmd.html"
+"config.html#config_messages"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
